@@ -8,7 +8,7 @@ from invenio_vocabularies.services.schema import i18n_strings
 from marshmallow import fields as ma_fields
 from marshmallow import validate as ma_validate
 from marshmallow_utils.fields import edtfdatestring as mu_fields_edtf
-from oarepo_runtime.i18n.schema import I18nSchema
+from oarepo_runtime.i18n.schema import I18nStrField, MultilingualField
 from oarepo_runtime.validation import validate_date
 from oarepo_vocabularies.services.schemas import HierarchySchema
 
@@ -22,7 +22,7 @@ from nr_metadata.schema.identifiers import (
 class AdditionalTitlesSchema(ma.Schema):
     """AdditionalTitlesSchema schema."""
 
-    title = ma_fields.Nested(lambda: I18nSchema())
+    title = I18nStrField()
     titleType = ma_fields.String()
 
 
@@ -82,7 +82,7 @@ class NRSubjectSchema(ma.Schema):
     """NRSubjectSchema schema."""
 
     subjectScheme = ma_fields.String()
-    subject = ma_fields.List(ma_fields.Nested(lambda: I18nSchema()))
+    subject = MultilingualField(I18nStrField())
     valueURI = ma_fields.String()
     classificationCode = ma_fields.String()
 
@@ -243,9 +243,9 @@ class NRCommonMetadataSchema(ma.Schema):
     )
     languages = ma_fields.List(ma_fields.Nested(lambda: NRLanguageVocabularySchema()))
     notes = ma_fields.List(ma_fields.String())
-    abstract = ma_fields.List(ma_fields.Nested(lambda: I18nSchema()))
-    methods = ma_fields.List(ma_fields.Nested(lambda: I18nSchema()))
-    technicalInfo = ma_fields.List(ma_fields.Nested(lambda: I18nSchema()))
+    abstract = MultilingualField(I18nStrField())
+    methods = MultilingualField(I18nStrField())
+    technicalInfo = MultilingualField(I18nStrField())
     rights = ma_fields.List(ma_fields.Nested(lambda: NRLicenseVocabularySchema()))
     accessRights = ma_fields.Nested(lambda: NRAccessRightsVocabularySchema())
     relatedItems = ma_fields.List(ma_fields.Nested(lambda: NRRelatedItemSchema()))
@@ -254,7 +254,7 @@ class NRCommonMetadataSchema(ma.Schema):
     )
     version = ma_fields.String()
     geoLocations = ma_fields.List(ma_fields.Nested(lambda: NRGeoLocationSchema()))
-    accessibility = ma_fields.List(ma_fields.Nested(lambda: I18nSchema()))
+    accessibility = MultilingualField(I18nStrField())
     series = ma_fields.List(ma_fields.Nested(lambda: NRSeriesSchema()))
     externalLocation = ma_fields.Nested(lambda: NRExternalLocationSchema())
     originalRecord = ma_fields.String()
